@@ -7,7 +7,8 @@ no warnings "experimental::lexical_subs";
 # This action will render a template
 sub welcome {
   my $self = shift;
-  my $msg  = 'Добре дошли в приложението „Слово“!';
+  my $msg
+    = 'Добре дошли в приложението „Слово“!';
 
   # Render template "example/welcome.html.ep" with message
   return $self->render(msg => $msg);
